@@ -1,18 +1,18 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 
+from trytond.modules.stock.stock_reporting_margin import Abstract
 from trytond.pool import Pool
 
-from trytond.modules.stock.stock_reporting_margin import Abstract
+from . import carrier, stock, stock_reporting_margin
+from .stock import ShipmentCostMixin
 
-from . import stock
-from . import stock_reporting_margin
-
-__all__ = ['register']
+__all__ = ['register', 'ShipmentCostMixin']
 
 
 def register():
     Pool.register(
+        carrier.Carrier,
         stock.Move,
         stock.ShipmentOut,
         stock.ShipmentOutReturn,
